import {
  fetchPlaces,
  fetchRandomPlace,
  fetchVideosByPlace,
  fetchPlaceItemCount 
} from '../utils/api';
import { APIError } from './errors';
import { getItem, setItem } from '../utils/safe-storage';
import { addVideosToState } from './videos';
import { 
  START_LOADING_ALL_PLACES, 
  LOADED_ALL_PLACES,
  START_LOADING_RANDOM_PLACE,
  LOADED_RANDOM_PLACE
} from './action_types';

export function getAllPlaces() {
  return dispatch => {
    dispatch(startLoadingAllPlaces());
    // this calls the API
    fetchPlaces()
      .then(places => {
        dispatch(loadedPlaces(places));
      }).catch(error => {
        dispatch(APIError(error));
      })
  };
};

function startLoadingAllPlaces() {
  return {
    type: START_LOADING_ALL_PLACES
  };
};

function loadedPlaces(places) {
  return {
    type: LOADED_ALL_PLACES,
    payload: places
  };
};


// actions :
// - async actions
// - simple: return action type and payload.
export function getRandomPlaceVideos(numVideos=3) {
  return dispatch => {
    dispatch(loadingRandomPlaceVideos());
    fetchRandomPlace()
      .then(place => {
        console.log('place', place);
        return fetchPlaceItemCount(place.name)
          .then(itemCount => {
            fetchVideosByPlace(place.name, 0, numVideos)
              .then(videos => {
                console.log('place videos', videos);
                dispatch(addVideosToState(videos));
                dispatch(loadedRandomPlaceVideos(place, itemCount, videos))
              });            
          })
  
      })
      .catch(e => {
        console.log('error', e);
      })
  };
};

function loadedRandomPlaceVideos(place, itemCount, videos) {
  return {
    type: LOADED_RANDOM_PLACE,
    payload: {
      place: place,
      itemCount: itemCount,
      videos: videos
    }
  };
};

function loadingRandomPlaceVideos() {
  return {
    type: START_LOADING_RANDOM_PLACE
  };
};